#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    IPv4Address,
    ListOf,
    MonitoringState,
    TextAscii,
    TextUnicode,
    Tuple,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_vpn_tunnel():
    return Dictionary(elements=[
        ("tunnels",
         ListOf(
             Tuple(
                 title=("VPN Tunnel Endpoints"),
                 elements=[
                     IPv4Address(
                         title=_("IP-Address or Name of Tunnel Endpoint"),
                         help=_(
                             "The configured value must match a tunnel reported by the monitored "
                             "device."),
                         allow_empty=False,
                     ),
                     TextUnicode(
                         title=_("Tunnel Alias"),
                         help=_(
                             "You can configure an individual alias here for the tunnel matching "
                             "the IP-Address or Name configured in the field above."),
                     ),
                     MonitoringState(
                         default_value=2,
                         title=_("State if tunnel is not found"),
                     )
                 ],
             ),
             add_label=_("Add tunnel"),
             movable=False,
             title=_("VPN tunnel specific configuration"),
         )),
        ("state",
         MonitoringState(
             title=_("Default state to report when tunnel can not be found anymore"),
             help=_("Default state if a tunnel, which is not listed above in this rule, "
                    "can no longer be found."),
         )),
    ],)


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="vpn_tunnel",
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_("IP-Address of Tunnel Endpoint")),
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_vpn_tunnel,
        title=lambda: _("VPN Tunnel"),
    ))
